@@ -13,13 +13,10 @@
 #include "../record/record.h"
 
 class Storage;
-class Options;
 
     // ConnectionsConsumer object constructed in natfork/childprocess
 class ConnectionsConsumer: public FBB::SignalHandler
 {
-    Options const &d_options;
-
     RotatingStream d_logDataStream;
     std::ostream &d_stdMsg;
     Storage &d_storage;
