@@ -2,7 +2,6 @@
 
 ConnectionsConsumer::ConnectionsConsumer(ostream &stdMsg, Storage &storage)
 :
-    d_options(Options::instance()),
     d_logDataStream(header),
     d_stdMsg(stdMsg),
     d_storage(storage),
@@ -15,13 +14,16 @@ ConnectionsConsumer::ConnectionsConsumer(ostream &stdMsg, Storage &storage)
         { Record::TCP,      &d_tcp  }, 
         { Record::UDP,      &d_udp  }, 
     },
-    d_ttl(d_options.ttl())
+    d_ttl(Options::instance().ttl())
 {
-    string path;
-    if (ArgConfig::instance().option(&path, "log-data") != 0)
-        d_logDataStream.open(path);                 // prepare for data log
+    if (
+        string logData = Options::instance().logData();
+        not logData.empty()
+    )
+        d_logDataStream.open(logData, false);       // prepare for data log
 
     Signal::instance().add(SIGINT, *this);
     Signal::instance().add(SIGTERM, *this);
 }
 
+
