@@ -4,11 +4,10 @@
 #include <iosfwd>
 
 #include <bobcat/pattern>
-#include <bobcat/signal>
 #include <bobcat/fork>
 #include <bobcat/pipe>
 
-#include "../producer/producer.h"
+#include "../producersignals/producersignals.h"
 
 class Options;
 class Storage;
@@ -18,8 +17,7 @@ namespace FBB
     class Pattern;
 }
 
-class ConntrackProducer: public Producer, public FBB::Fork, 
-                         public FBB::SignalHandler
+class ConntrackProducer: public ProducerSignals, public FBB::Fork
 {
     FBB::Pipe d_pipe;
     Options &d_options;
@@ -28,22 +26,42 @@ class ConntrackProducer: public Producer, public FBB::Fork,
 
     bool d_signaled = false;
 
+    bool (ConntrackProducer::*d_tcpUdp)(std::string const &line);
+    bool (ConntrackProducer::*d_icmp)(std::string const &line);
+
     static FBB::Pattern s_tcpudp;
     static FBB::Pattern s_icmp;
+    static char const s_nfConntrackAcct[];
 
     public:
         ConntrackProducer(std::ostream &stdMsg, Storage &storage);
         ~ConntrackProducer();
 
     private:
-        void process(std::string const &line);
+        void activateByteCounts() const;
+        bool icmp(std::string const &line);     // process ICMP connections
+        bool notUsed(std::string const &line);  // false: used for unused 
+                                                //        connection types
+        void process(std::string const &line);  // process the conntrack info
+        void setTcpUdp(size_t protocolType,     // set d_tcpUdp for TCP/UDP
+                       char const *label);
+        bool tcpUdp(std::string const &line);   // process TCP/UDP connections
 
-        void run()                          override;
-        void signalHandler(size_t signum)   override;
-        void parentProcess()                override;
         void childProcess()                 override;
         void childRedirections()            override;
+        void parentProcess()                override;
         void parentRedirections()           override;
+        void run()                          override;
+        void signalHandler(size_t signum)   override;
 };
         
 #endif
+
+
+
+
+
+
+
+
+
