@@ -3,14 +3,13 @@
 
 #include <iosfwd>
 
-#include <bobcat/signal>
 #include <bobcat/semaphore>
 
-#include "../producer/producer.h"
+#include "../producersignals/producersignals.h"
 
 class Storage;
 
-class DevicesProducer: public Producer, public FBB::SignalHandler
+class DevicesProducer: public ProducerSignals//, public FBB::SignalHandler
 {
     std::ostream &d_stdMsg;
     Storage &d_storage;
@@ -24,16 +23,8 @@ class DevicesProducer: public Producer, public FBB::SignalHandler
         ~DevicesProducer() override;
 
     private:
-        void handleSignals();
-
         void run()                          override;
         void signalHandler(size_t signum)   override;
 };
         
 #endif
-
-
-
-
-
-
