@@ -2,7 +2,7 @@
 
 void IPbase::vByteCounts(Record const &record) const
 {
-    d_stdMsg <<
+    d_stdMsg << " "
             "sent: "     << setw(10) << record.sentBytes() << ", "
             "received: " << setw(10) << record.receivedBytes();
 }
