@@ -10,24 +10,24 @@ namespace   // the anonymous namespace can be used here
         Arg::LongOption("conntrack-device", Arg::Required),
         Arg::LongOption("conntrack-ip-header-size", Arg::Required),
         Arg::LongOption("conntrack-restart", Arg::Required),
-        Arg::LongOption("debug", Arg::None),
+        Arg::LongOption("debug", Arg::NoArg),
         Arg::LongOption("help", 'h'),
         Arg::LongOption("log", Arg::Required),
         Arg::LongOption("log-data", Arg::Required),
         Arg::LongOption("log-rotate", Arg::Required),
-        Arg::LongOption("no-bytes", Arg::None),
-        Arg::LongOption("no-daemon", Arg::None),
-        Arg::LongOption("no-dst", Arg::None),
-        Arg::LongOption("no-via", Arg::None),
+        Arg::LongOption("no-bytes", Arg::NoArg),
+        Arg::LongOption("no-daemon", Arg::NoArg),
+        Arg::LongOption("no-dst", Arg::NoArg),
+        Arg::LongOption("no-via", Arg::NoArg),
         Arg::LongOption("pid-file", 'p'),
         Arg::LongOption("protocol", 'P'),
-        Arg::LongOption("rotate", Arg::None),
-        Arg::LongOption("rotate-data", Arg::None),
+        Arg::LongOption("rotate", Arg::NoArg),
+        Arg::LongOption("rotate-data", Arg::NoArg),
         Arg::LongOption("stdout", 's'),
         Arg::LongOption("syslog-facility", Arg::Required),
         Arg::LongOption("syslog-priority", Arg::Required),
         Arg::LongOption("syslog-tag", Arg::Required),
-        Arg::LongOption("terminate", Arg::None),
+        Arg::LongOption("terminate", Arg::NoArg),
         Arg::LongOption("time", 't'),
         Arg::LongOption("ttl", 'T'),
         Arg::LongOption("verbose", 'V'),
@@ -50,10 +50,12 @@ try
 
     ArgConfig &arg = ArgConfig::initialize("c:hp:P:st:T:vV", 
                         longOptions, longEnd, argc, argv);
-    
+
+    arg.versionHelp(usage, Icmbuild::version, 1);
+
     if (Options::instance().forwardOption())
         return 0;
-
+    
     arg.versionHelp(usage, Icmbuild::version, 1);
 
     NatFork natfork;
