@@ -24,7 +24,13 @@ void NatFork::childProcess()
     d_stdMsg << "processing: " << d_options.protocolNames() << endl;
 
     if (d_options.daemon())
+    {
         prepareDaemon();
+                                    // signals sent by Options::rotate[Data]
+                                    // handled by NatFork::signalHandler
+        Signal::instance().add(SIGHUP, *this);      // for --rotate
+        Signal::instance().add(SIGALRM, *this);     // for --rotate-data
+    }
 
     RotatingStreambuf::startThread();
 
