@@ -1,7 +1,7 @@
 #include "natfork.ih"
 
-void NatFork::conntrackMode()
-{
+void NatFork::conntrackMode()           // check the availability of the 
+{                                       // conntrack device
     string conntrack = d_options.conntrackCommand();
 
     size_t pos = conntrack.find_first_of(" \t");
@@ -11,6 +11,6 @@ void NatFork::conntrackMode()
     if (access(conntrack.c_str(), R_OK | X_OK) != 0)
     {
         d_stdMsg << "[Fatal] can't execute " << conntrack << endl;
-        throw Options::FAILED;
+        throw 1; 
     }
 }
