@@ -5,6 +5,6 @@ void NatFork::setupNonDaemonMsg()
     if (not d_options.verbose())
         imsg.off();
 
-    if (not d_options.warnings())
-        wmsg.off();
+//    if (not d_options.warnings())
+//        wmsg.off();
 }
