@@ -8,7 +8,7 @@ void NatFork::setupStdMsg()
     if (d_options.log().empty())        // no messages
         return;
 
-    if (d_options.log() == "syslog")
+    if (d_options.log() == "syslog")    // using syslog, and return
     {
         d_syslog.reset(
             new SyslogStream(
@@ -27,8 +27,11 @@ void NatFork::setupStdMsg()
         return;
     }
 
-    // a log-file path was specified: create rotating stream 
-    d_log.open(d_options.log());
+                                        // a log-file path was specified: 
+                                        // create the rotating stream 
+
+    d_log.open(d_options.log(), true);  // forwards --log to RotatingStreambuf
+
     d_multiStreambuf.insert(d_log);
 }
 
