@@ -1,6 +1,7 @@
 #ifndef INCLUDED_OPTIONS_
 #define INCLUDED_OPTIONS_
 
+#include <memory>
 #include <iosfwd>
 #include <ctime>
 #include <string>
@@ -112,7 +113,7 @@ struct Options: public IP_Types
         static std::unordered_map<Protocol, std::string> const 
                                                            s_protocol2name;
 
-        static Options *s_options;
+        static std::unique_ptr<Options> s_options;
 
     public:
         static Options &instance();
