@@ -2,22 +2,33 @@
 
 void Options::setLogParams()
 {
-    string value;
+    // at construction time: d_rotateFreq = 0;
 
-    if (not d_arg.option(&d_log, "log"))     
+    d_arg.option(&d_logData, "log-data");                   // maybe log
+                                                            // table data
+
+    if (not d_arg.option(&d_log, "log"))     // no log spec: use syslog
     {
         d_log = "syslog";
-        if (not d_arg.option(&d_syslogTag, "syslog-tag"))
-            d_syslogTag = s_defaultSyslogIdent;
+
+        if (not d_arg.option(&d_syslogTag, "syslog-tag"))   // specific or 
+            d_syslogTag = s_defaultSyslogIdent;             // default log-tag
     
         setSyslogFacility();
         setSyslogPriority();
+
+        return;
     }
-    else if (d_log == "off")                    // no logging
+                                                // log specification indicates
+    if (d_log == "off")                         // no logging
+    {
         d_log.clear();
+        return;
+    }
 
-    d_arg.option(&d_logData, "log-data");
+    // path to the log-file was specified
 
+    string value;
     if (d_arg.option(&value, "log-rotate"))     // log file rotation in days
     {
         istringstream in{ value };
@@ -47,7 +58,11 @@ void Options::setLogParams()
             d_rotateTimeSpec.pop_back();
 
         if (isdigit(in.peek()))
-             in >> d_nRotations;
+        {
+            in >> d_nRotations;
+            if (d_nRotations == 0)
+                d_nRotations = 1;
+        }
         else if (in.peek() == EOF)
             d_nRotations = 1;
         else
