@@ -9,5 +9,5 @@ void Options::setMode()
     else if (d_arg.nArgs() == 6)
         d_mode = TCPDUMP;
     else
-        throw Exception() << "Mode specification error";
+        throw Exception{} << "Mode specification error";
 }
