@@ -8,19 +8,16 @@ class RotatingStream: private RotatingStreambuf, public std::ostream
 {
     public:
         RotatingStream(void (*header)(std::ostream &) = 0);
-        void open(std::string const &name);
+
+        void open(std::string const &name,  // forwards to RotatingStreambuf
+                  bool stdLog);             // true: std logs, false: data log
+
         static void notify();
 };
 
-inline RotatingStream::RotatingStream(void (*header)(std::ostream &))
-:
-    RotatingStreambuf(header),
-    std::ostream(this)
-{}
-        
-inline void RotatingStream::open(std::string const &name)
+inline void RotatingStream::open(std::string const &name, bool stdLog)
 {
-    RotatingStreambuf::open(name);
+    RotatingStreambuf::open(name, stdLog);
 }
 
 inline void RotatingStream::notify()
