@@ -6,17 +6,13 @@ void RotatingStreambuf::rotateThread()
     Options const &options = Options::instance();
 
     size_t freq = options.rotateFreq();
-    size_t nRotations = options.nRotations();
 
-    if (freq == 0 || nRotations == 0)
+    if (freq == 0)                              // no rotation
         return;
 
     freq *= options.rotateFactor();
 
 
     while (s_semaphore.wait_for(chrono::minutes(freq)) == cv_status::timeout)
-    {
-        for (RotatingStreambuf *rs: s_rotate)
-            rs->rotate(nRotations);
-    }
+        rotate();
 }
