@@ -3,6 +3,6 @@
 // static
 void RotatingStreambuf::startThread()
 {
-    if (not s_rotate.empty())
+    if (rotationsRequested())
         s_rotateThread = thread{ rotateThread };
 }
