@@ -5,7 +5,7 @@
 
 #include <bobcat/semaphore>
 
-#include "../record/record.h"
+class Record;
 
 class Storage
 {
@@ -17,24 +17,24 @@ class Storage
     FBB::Semaphore d_available{ AVAIL };
     FBB::Semaphore d_filled{ 0 };
 
-    Record d_record;                        // retrieved from the queue
+    Record *d_record;                       // retrieved from the queue
 
     std::mutex d_mutex;    
-    std::queue<Record> d_queue;
+    std::queue<Record *> d_queue;
     bool d_empty = false;                   // indicates no more data will
                                             // arrive 
     public:
-        Storage();                          // could be default?
+        Storage() = default;
         Storage(Storage const &) = delete;
 
-        void consumeWait();                
-        void produceNotify();
-        void push(Record &&src);
-        Record &fetch();                    // fetch the next record
-        size_t size() const;
+        void consumeWait();                 // i
+        void produceNotify();               // i
+        void push(Record *src);
+        Record *fetch();                    // fetch the next record
+        size_t size() const;                // i
 
-        bool empty() const;
-        void setEmpty();                     // sets d_empty to true
+        bool empty() const;                 // i
+        void setEmpty();                    // i - sets d_empty to true
 };
 
 inline bool Storage::empty() const
@@ -42,7 +42,7 @@ inline bool Storage::empty() const
     return d_empty && d_queue.empty();
 }
 
-inline void Storage::setEmpty()
+inline void Storage::setEmpty()         
 {
     d_empty = true;
     d_filled.notify();
