@@ -57,13 +57,15 @@ Where:
       --protocol (-P) spec - spec: protocols handled by )"; 
 
 
-    char const optionRot[] = R"(Use colon separated combinations of
+    char const optionRot[] = R"(
+                           Use colon separated combinations of
                            tcp (default), udp and icmp, or use `all'
       --rotate           - the log-files of a separately running process are 
                            rotated
-      --rotate-data      - the log-data files of a separately running )";
+      --rotate-data      - the log-data files of `)";
 
-    char const optionS[] = R"( process are rotated
+    char const optionS[] = R"('
+                           (a separately called process) are rotated
       -S                 - systemd fix: specify this as first argument when
                            starting )"; 
 
